"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const vite_plugin_vue_markdown_1 = __importDefault(require("vite-plugin-vue-markdown"));
function Preview() {
    const markdown = (0, vite_plugin_vue_markdown_1.default)();
    const previewBlockReg = /\<(preview)[\s\S]*?\>([\s\S]*?)\<\/\1\>/g;
    const virtualModuleId = 'virtual:vue-component-preview';
    const resolvedVirtualModuleId = '\0' + virtualModuleId;
    return {
        name: 'vite-plugin-vue-component-preview',
        resolveId(id) {
            if (id === virtualModuleId) {
                return resolvedVirtualModuleId;
            }
        },
        load(id) {
            if (id === resolvedVirtualModuleId) {
                return `
import { defineAsyncComponent, defineComponent, h, Suspense } from 'vue';

export default function installPreview(app) {
	if (location.pathname === '/__preview') {

		const url = new URL(location.href);
		let fileName = url.hash.slice(1);

		// fix windows path for vite
		fileName = fileName.replace(/\\\\\\\\/g, '/');
		if (fileName.indexOf(':') >= 0) {
			fileName = fileName.split(':')[1];
		}

		const Component = defineAsyncComponent(async () => import(fileName));
		const Layout = defineAsyncComponent(async () => import(fileName + '?preview'));
		const Previewer = defineComponent({
			setup: function () {
				return () => h(Suspense, undefined, [h(Layout, undefined, {
					default: (props) => h(Component, props)
				})]);
			},
		});
		// @ts-expect-error
		app._component.setup = Previewer.setup;
	}
}`;
            }
        },
        transform(code, id) {
            var _a;
            if (id.endsWith('.vue')) {
                // remove preview block
                const previewBlock = code.match(previewBlockReg);
                if (previewBlock) {
                    const index = (_a = previewBlock.index) !== null && _a !== void 0 ? _a : code.indexOf(previewBlock[0]);
                    code = code.substring(0, index) + code.substring(index + previewBlock[0].length);
                }
            }
            else if (id.endsWith('.vue?preview')) {
                // extract preview block content
                const previewBlock = code.match(previewBlockReg);
                if (previewBlock) {
                    const startTagEnd = previewBlock[0].indexOf('>') + 1;
                    const endTagStart = previewBlock[0].lastIndexOf('</');
                    code = previewBlock[0].substring(startTagEnd, endTagStart);
                    // @ts-expect-error
                    code = markdown.transform(code, 'foo.md');
                }
            }
            return code;
        },
    };
}
exports.default = Preview;
